/**
 * Copyright (c) 2009-2011 Zauber S.A. <http://www.zaubersoftware.com/>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.zauberlabs.commons.ws.security;

import net.sf.staccatocommons.check.Ensure;



/**
 * Basic Credentials of a user, with username and password  
 * 
 * 
 * @author Gaston Prieto
 * @since Apr 10, 2012
 */
public class BasicCredential implements Credential {

    private final String username;
    private final String password;

    /**
     * Creates the BasicCredentials.
     *
     * @param username
     * @param password
     */
    public BasicCredential(final String username, final String password) {
        Ensure.that().isNotEmpty("username", username);
        Ensure.that().isNotEmpty("password", password);
        this.username = username;
        this.password = password;
    }

    /** @see com.zauberlabs.commons.ws.security.Credential#getUsername() */
    @Override
    public String getUsername() {
        return username;
    }

    /** @see com.zauberlabs.commons.ws.security.Credential#getPassword() */
    @Override
    public String getPassword() {
        return password;
    }

}
